#[repr(C)]pub struct RawFlux {
pub id_source: u32,
pub id_target: u32,
pub flux_source_target: f64,
pub flux_target_source: f64,
}Expand description
Represents a single raw flux interaction.
This struct is used to store individual flux interactions between a source and a target, including the flux values in both directions.
Fields
id_source: u32The identifier for the source in the flux interaction.
id_target: u32The identifier for the target in the flux interaction.
flux_source_target: f64The flux value from the source to the target.
flux_target_source: f64The flux value from the target to the source.