#[repr(C)]pub struct ScalarFileHeader {
pub n_zone: u32,
}Expand description
Represents the header of a scalar file.
This header contains metadata about the scalar data stored in the file.
Fields
n_zone: u32The number of zones in the scalar file data.