pub struct SimpleTransitioner {
state_buffer: Vec<Arc<IterationState>>,
time_per_flomap: f64,
remaining_time: f64,
current_index: usize,
}Fields
state_buffer: Vec<Arc<IterationState>>time_per_flomap: f64remaining_time: f64current_index: usizeTrait Implementations
Sourceimpl FlowMapTransitioner for SimpleTransitioner
impl FlowMapTransitioner for SimpleTransitioner
Sourcefn advance_arc(
&mut self,
_current_time: f64,
time_step: f64,
) -> Arc<IterationState>
fn advance_arc( &mut self, _current_time: f64, time_step: f64, ) -> Arc<IterationState>
Sourcefn get_at(&self, idx: usize) -> Option<Arc<IterationState>>
fn get_at(&self, idx: usize) -> Option<Arc<IterationState>>
Retrieves the state at the given buffer index as an owned
Arc. Read moreSourcefn advance(&mut self, _current_time: f64, time_step: f64) -> &IterationState
fn advance(&mut self, _current_time: f64, time_step: f64) -> &IterationState
Advances the internal state according to
current_time and
time_step, and returns a borrowed reference to the active
IterationState. Read moreSourcefn need_advance(&self, _current_time: f64, _time_step: f64) -> bool
fn need_advance(&self, _current_time: f64, _time_step: f64) -> bool
Returns
true if the flow-map index should advance when evaluating
the given current_time and time_step. Read moreSourcefn get_current(&self) -> &IterationState
fn get_current(&self) -> &IterationState
Returns the current state as a borrowed reference.
Sourcefn get_current_arc(&self) -> Arc<IterationState>
fn get_current_arc(&self) -> Arc<IterationState>
Returns the current state as an owned
Arc<IterationState>.Sourcefn new(time_per_flomap: f64, buffer: FlowMapBuffer) -> Self
fn new(time_per_flomap: f64, buffer: FlowMapBuffer) -> Self
Constructs a new transitioner from the duration of each flow-map (
time_per_flomap)
and a validated FlowMapBuffer. Read moreAuto Trait Implementations
impl Freeze for SimpleTransitioner
impl RefUnwindSafe for SimpleTransitioner
impl Send for SimpleTransitioner
impl Sync for SimpleTransitioner
impl Unpin for SimpleTransitioner
impl UnsafeUnpin for SimpleTransitioner
impl UnwindSafe for SimpleTransitioner