pub trait CMCaseReader {
// Required method
fn read_case(path: &Path) -> Result<CMCase, DataError>;
}Expand description
A trait for reading a CMCase from a specified path.
Implement this trait for types that are capable of reading a case configuration from disk or another storage medium.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.